==> logicalpy-1.1.0.tar.gz: logicalpy-1.1.0/README.md <==
# LogicalPy

[![PyPi version](https://badgen.net/pypi/v/logicalpy/)](https://pypi.org/project/logicalpy)
[![License](https://img.shields.io/github/license/Cubix1729/logicalpy)](https://github.com/Cubix1729/logicalpy/blob/master/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

LogicalPy is a Python library providing basic functionalities for manipulating propositional logic.

## Description

The library allows to work with classical propositional logic formulae.
The main features include:

 - The construction of logical formulae either directly or from a string
 - The visualisation of truth tables
 - The implementation of semantic notions: satisfiability, entailment...
 - The conversion to normal forms (NNF, CNF, or DNF)
 - Automated theorem proving with the resolution procedure

For the complete documentation, see [https://cubix1729.github.io/logicalpy/](https://cubix1729.github.io/logicalpy/).

## Installation

With pip:
```
pip install logicalpy
```

Note that the library needs a Python version higher than 3.9.

## Contributing

If you want to contribute to this (small) project, you can [open an issue](https://github.com/Cubix1729/logicalpy/issues)
to report a bug or request a feature, or [make a pull request](https://github.com/Cubix1729/logicalpy/pulls).

## Tests

To run the the tests, clone the repository, go into the `tests` directory and run `python -m unittest`.

## License

This project is licensed under the MIT license.

==> logicalpy-1.2.0.tar.gz: logicalpy-1.2.0/README.md <==
# LogicalPy

[![PyPI version](https://img.shields.io/pypi/v/logicalpy)](https://pypi.org/project/logicalpy)
[![License](https://img.shields.io/github/license/Cubix1729/logicalpy)](https://github.com/Cubix1729/logicalpy/blob/master/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Python versions](https://img.shields.io/pypi/pyversions/logicalpy)](https://pypi.python.org/pypi/logicalpy)

LogicalPy is a Python library providing basic functionalities for manipulating propositional logic.

## Description

The library allows to work with classical propositional logic formulae.
The main features include:

 - The construction of logical formulae either directly or from a string
 - The visualisation of truth tables
 - The implementation of semantic notions: satisfiability, entailment...
 - The conversion to normal forms (NNF, CNF, or DNF)
 - The implementation of a Hilbert-style proof system
 - Automated theorem proving with the resolution procedure

The library also supports LaTex code generation for most of its functionalities.

For the complete documentation, see [https://cubix1729.github.io/logicalpy/](https://cubix1729.github.io/logicalpy/).

## Installation

With pip:
```
pip install logicalpy
```

Note that the library needs a Python version higher than 3.9.

## Contributing

If you want to contribute to this (small) project, you can [open an issue](https://github.com/Cubix1729/logicalpy/issues)
to report a bug or request a feature, or [make a pull request](https://github.com/Cubix1729/logicalpy/pulls).

## Tests

To run the the tests, first clone the repository, go into the `logicalpy` directory and locally install the project with `pip install -e .`
Then, go into the `tests` directory and run `python -m unittest`.

## License

This project is licensed under the MIT license.
